Admin Tasks
-----------

Status
------

The status tab displays the status of the Live DB updaters.
The statuses are:

**Is Running** - Displays if the updater is active.

**Queue Size** - Displays the number of values waiting for the Updater.

**Total Processed** - Displays the number of values updated.

**Last Error** - Displays a description of the last error encountered by the
Updater.

.. image:: live_db_status.png
    :align: center

Edit Settings
-------------

To toggle the updater:

#. Click on the **Value** button. Toggle the value true or false.
#. Click **Save**

.. image:: live_db_edit_settings.png
    :align: center
